/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.logging.log4j.plugins.di.resolver;

import java.lang.reflect.ParameterizedType;
import java.lang.reflect.Type;
import org.apache.logging.log4j.plugins.di.Key;
import org.apache.logging.log4j.plugins.di.spi.FactoryResolver;

public abstract class AbstractPluginFactoryResolver<T> implements FactoryResolver<T> {
    @Override
    public boolean supportsKey(final Key<?> key) {
        if (key.getNamespace().isEmpty()) {
            return false;
        }
        final Type type = key.getType();
        if (!(type instanceof final ParameterizedType parameterizedType)) {
            return false;
        }
        final Type rawType = parameterizedType.getRawType();
        final Type[] typeArguments = parameterizedType.getActualTypeArguments();
        if (typeArguments.length == 0) {
            return false;
        }
        return supportsType(rawType, typeArguments);
    }

    protected abstract boolean supportsType(final Type rawType, final Type... typeArguments);
}
